# onnx.external_data_helper

## convert_model_from_external_data

```{eval-rst}
.. autofunction:: onnx.external_data_helper.convert_model_from_external_data
```

## convert_model_to_external_data

```{eval-rst}
.. autofunction:: onnx.external_data_helper.convert_model_to_external_data
```

## ExternalDataInfo

```{eval-rst}
.. autoclass:: onnx.external_data_helper.ExternalDataInfo
```

## load_external_data_for_model

```{eval-rst}
.. autofunction:: onnx.external_data_helper.load_external_data_for_model
```

## load_external_data_for_tensor

```{eval-rst}
.. autofunction:: onnx.external_data_helper.load_external_data_for_tensor
```

## remove_external_data_field

```{eval-rst}
.. autofunction:: onnx.external_data_helper.remove_external_data_field
```

## save_external_data

```{eval-rst}
.. autofunction:: onnx.external_data_helper.save_external_data
```

## set_external_data

```{eval-rst}
.. autofunction:: onnx.external_data_helper.set_external_data
```

## write_external_data_tensors

```{eval-rst}
.. autofunction:: onnx.external_data_helper.write_external_data_tensors
```
